@@ -15,6 +15,7 @@ class Configuration:
         stt_model: str = "nova-3",
         stt_prompt: str = "",
         stt_endpointing: int = 300,
+        stt_language: str = "en",
         recording_enabled: bool = False,
         timeout: int = 5,
     ):
@@ -23,6 +24,7 @@ class Configuration:
         self.stt_model = stt_model
         self.stt_prompt = stt_prompt
         self.stt_endpointing = stt_endpointing
+        self.stt_language = stt_language
         self.recording_enabled = recording_enabled
         self.timeout = timeout
 
@@ -42,6 +44,7 @@ class Configuration:
             "stt_model": self.stt_model,
             "stt_prompt": self.stt_prompt,
             "stt_endpointing": self.stt_endpointing,
+            "stt_language": self.stt_language,
             "recording_enabled": self.recording_enabled,
             "timeout": self.timeout,
         }
