@@ -38,7 +38,7 @@ class TextEvent(Event):
 
 
 class TextToSpeechEvent(Event):
-    def __init__(self, text: str, voice="nova", cache=True, interruptable=True):
+    def __init__(self, text: str, voice="nova", cache=True, interruptable=True, instructions="", speed=1.0):
         super().__init__(
             "text_to_speech",
             {
@@ -46,6 +46,8 @@ class TextToSpeechEvent(Event):
                 "voice": voice,
                 "cache": cache,
                 "interruptable": interruptable,
+                "instructions": instructions,
+                "speed": speed,
             },
         )
 
@@ -156,7 +158,14 @@ def event_from_str(event_str: str) -> Event:
         "silence": lambda: SilenceEvent(data["duration"]),
         "start": StartEvent,
         "stop": StopEvent,
-        "text_to_speech": lambda: TextToSpeechEvent(data["text"], data["voice"]),
+        "text_to_speech": lambda: TextToSpeechEvent(
+            data["text"], 
+            data.get("voice", "nova"),
+            data.get("cache", True),
+            data.get("interruptable", True),
+            data.get("instructions", ""),
+            data.get("speed", 1.0)
+        ),
         "text": lambda: TextEvent(data["source"], data["text"]),
         "timeout": TimeoutEvent,
         "transfer_call": lambda: TransferCallEvent(data["phone_number"]),
